# easypubsub
[![Tests](https://github.com/matpompili/easypubsub/actions/workflows/python-package.yml/badge.svg)](https://github.com/matpompili/easypubsub/actions/workflows/python-package.yml)
[![License: MIT](https://img.shields.io/badge/license-MIT-brightgreen)](https://github.com/matpompili/easypubsub/blob/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/easypubsub)](https://pypi.org/project/easypubsub/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

EasyPubSub is a simple wrapper around PyZMQ that provides an easy interface to Publish Subscribe.
